async fn deref_obj<'a>(
    obj_or_link: ObjectOrLink<'a>,
    db: &'a Database,
    remote: &'a RemoteAccessor
) -> Result<Object<'a>, DerefError>
If the given ObjectOrLink is an object, returns that, otherwise attempts to fetch the object from the database, falling back to fetching it from its origin server, and returns that.